@@ -23,6 +23,10 @@ SINGLETEST = 'singletest'
 EXCLUSION = 'exclusion'
 CUSTOMER = "customer"
 DBVALUES = [NONE, SNAPSHOT, FULL]
+CRAWL_AND_COMPLIANCE = "CRAWL_AND_COMPLIANCE"
+CRAWL = "CRAWL"
+COMPLIANCE = "COMPLIANCE"
+RUN_TYPE = [CRAWL_AND_COMPLIANCE, CRAWL, COMPLIANCE]
 CACHEDATA = None
 
 def generateid(name):
