@@ -6,6 +6,9 @@ from processor.template_processor.kubernetes_template_processor import Kubernete
 from processor.template_processor.yaml_template_processor import YamlTemplateProcessor
 from processor.template_processor.json_template_processor import JsonTemplateProcessor
 from processor.template_processor.helm_chart_template_processor import HelmChartTemplateProcessor
+from processor.template_processor.ack_processor import AckTemplateProcessor
+from processor.template_processor.aso_processor import AsoTemplateProcessor
+from processor.template_processor.kcc_processor import KccTemplateProcessor
 TEMPLATE_NODE_TYPES = {
     "cloudformation": AWSTemplateProcessor,
     "arm" : AzureTemplateProcessor,
@@ -14,5 +17,8 @@ TEMPLATE_NODE_TYPES = {
     "kubernetesObjectFiles" : KubernetesTemplateProcessor,
     "yaml" : YamlTemplateProcessor,
     "json": JsonTemplateProcessor,
-    "helmChart" : HelmChartTemplateProcessor
+    "helmChart" : HelmChartTemplateProcessor,
+    "ack" : AckTemplateProcessor, # AWS Controllers for Kubernetes
+    "aso" : AsoTemplateProcessor, # Azure Service Operator
+    "kcc" : KccTemplateProcessor # GCP Kubernetes Config Connector
 }
\ No newline at end of file
